==> parcel-bundler-vue-1.6.3.tgz: package/lib/packagers/HTMLPackager.js <==
'use strict';

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _from = require('babel-runtime/core-js/array/from');

var _from2 = _interopRequireDefault(_from);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _set = require('babel-runtime/core-js/set');

var _set2 = _interopRequireDefault(_set);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Packager = require('./Packager');
var posthtml = require('posthtml');
var path = require('path');
var urlJoin = require('../utils/urlJoin');

// https://www.w3.org/TR/html5/dom.html#metadata-content-2
var metadataContent = new _set2.default(['base', 'link', 'meta', 'noscript', 'script', 'style', 'template', 'title']);

var HTMLPackager = function (_Packager) {
  (0, _inherits3.default)(HTMLPackager, _Packager);

  function HTMLPackager() {
    (0, _classCallCheck3.default)(this, HTMLPackager);
    return (0, _possibleConstructorReturn3.default)(this, (HTMLPackager.__proto__ || (0, _getPrototypeOf2.default)(HTMLPackager)).apply(this, arguments));
  }

  (0, _createClass3.default)(HTMLPackager, [{
    key: 'addAsset',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(asset) {
        var html, siblingBundles;
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                html = asset.generated.html || '';

                // Find child bundles that have JS or CSS sibling bundles,
                // add them to the head so they are loaded immediately.

                siblingBundles = (0, _from2.default)(this.bundle.childBundles).reduce(function (p, b) {
                  return p.concat([].concat((0, _toConsumableArray3.default)(b.siblingBundles.values())));
                }, []).filter(function (b) {
                  return b.type === 'css' || b.type === 'js';
                });


                if (siblingBundles.length > 0) {
                  html = posthtml(this.insertSiblingBundles.bind(this, siblingBundles)).process(html, { sync: true }).html;
                }

                _context.next = 5;
                return this.dest.write(html);

              case 5:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function addAsset(_x) {
        return _ref.apply(this, arguments);
      }

      return addAsset;
    }()
  }, {
    key: 'addBundlesToTree',
    value: function addBundlesToTree(bundles, tree) {
      var head = find(tree, 'head');
      if (head) {
        var _content = head.content || (head.content = []);
        _content.push.apply(_content, (0, _toConsumableArray3.default)(bundles));
        return;
      }

      var html = find(tree, 'html');
      var content = html ? html.content || (html.content = []) : tree;
      var index = findBundleInsertIndex(content);

      content.splice.apply(content, [index, 0].concat((0, _toConsumableArray3.default)(bundles)));
    }
  }, {
    key: 'insertSiblingBundles',
    value: function insertSiblingBundles(siblingBundles, tree) {
      var bundles = [];

      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = (0, _getIterator3.default)(siblingBundles), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var bundle = _step.value;

          if (bundle.type === 'css') {
            bundles.push({
              tag: 'link',
              attrs: {
                rel: 'stylesheet',
                href: urlJoin(this.options.publicURL, path.basename(bundle.name))
              }
            });
          } else if (bundle.type === 'js') {
            bundles.push({
              tag: 'script',
              attrs: {
                src: urlJoin(this.options.publicURL, path.basename(bundle.name))
              }
            });
          }
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }

      this.addBundlesToTree(bundles, tree);
    }
  }]);
  return HTMLPackager;
}(Packager);

function find(tree, tag) {
  var res = void 0;
  tree.match({ tag: tag }, function (node) {
    res = node;
    return node;
  });

  return res;
}

function findBundleInsertIndex(content) {
  for (var index = 0; index < content.length; index++) {
    var node = content[index];
    if (node && node.tag && !metadataContent.has(node.tag)) {
      return index;
    }
  }

  return 0;
}

module.exports = HTMLPackager;

==> parcel-bundler-vue-2.0.0.tgz: package/lib/packagers/HTMLPackager.js <==
'use strict';

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _from = require('babel-runtime/core-js/array/from');

var _from2 = _interopRequireDefault(_from);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Packager = require('./Packager');
var posthtml = require('posthtml');
var path = require('path');
var urlJoin = require('../utils/urlJoin');

var HTMLPackager = function (_Packager) {
  (0, _inherits3.default)(HTMLPackager, _Packager);

  function HTMLPackager() {
    (0, _classCallCheck3.default)(this, HTMLPackager);
    return (0, _possibleConstructorReturn3.default)(this, (HTMLPackager.__proto__ || (0, _getPrototypeOf2.default)(HTMLPackager)).apply(this, arguments));
  }

  (0, _createClass3.default)(HTMLPackager, [{
    key: 'addAsset',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(asset) {
        var html, siblingBundles;
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                html = asset.generated.html || '';

                // Find child bundles that have JS or CSS sibling bundles,
                // add them to the head so they are loaded immediately.

                siblingBundles = (0, _from2.default)(this.bundle.childBundles).reduce(function (p, b) {
                  return p.concat([].concat((0, _toConsumableArray3.default)(b.siblingBundles.values())));
                }, []).filter(function (b) {
                  return b.type === 'css' || b.type === 'js';
                });


                if (siblingBundles.length > 0) {
                  html = posthtml(this.insertSiblingBundles.bind(this, siblingBundles)).process(html, { sync: true }).html;
                }

                _context.next = 5;
                return this.dest.write(html);

              case 5:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function addAsset(_x) {
        return _ref.apply(this, arguments);
      }

      return addAsset;
    }()
  }, {
    key: 'getHeadContent',
    value: function getHeadContent(tree) {
      var head = find(tree, 'head');
      if (!head) {
        var html = find(tree, 'html');
        head = { tag: 'head' };
        html.content.unshift(head);
      }

      if (!head.content) {
        head.content = [];
      }

      return head;
    }
  }, {
    key: 'insertSiblingBundles',
    value: function insertSiblingBundles(siblingBundles, tree) {
      var head = this.getHeadContent(tree);

      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = (0, _getIterator3.default)(siblingBundles), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var bundle = _step.value;

          if (bundle.type === 'css') {
            head.content.push({
              tag: 'link',
              attrs: {
                rel: 'stylesheet',
                href: urlJoin(this.options.publicURL, path.basename(bundle.name))
              }
            });
          } else if (bundle.type === 'js') {
            head.content.push({
              tag: 'script',
              attrs: {
                src: urlJoin(this.options.publicURL, path.basename(bundle.name))
              }
            });
          }
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }
    }
  }]);
  return HTMLPackager;
}(Packager);

function find(tree, tag) {
  var res = void 0;
  tree.match({ tag: tag }, function (node) {
    res = node;
    return node;
  });

  return res;
}

module.exports = HTMLPackager;
